==> modules.2.0.zip: lang/fr-help.php <==
<div class="help">
	<h1>Aide du plugin modules</h1>
	<img src="../../plugins/modules/icon.png" style="float:left">
	<p>Le plugin ne nécessite pas d'être configuré et est disponible sitôt activé</p>
	<p>La fonction de ce plugin se limite à injecter un widget dans vos pages.</p>
	<p> Ce widget pouvant embarquer différents modules, il peut-être utilisé plusieurs fois pour injecter différents modules dans vos pages à différents endroits.</p>
	<h2>A quoi sert ce widget?</h2>
	<p>Ce widget vous permet d'injecter dans vos page du texte( HTML, JavaScript,..)) et d'injecter du code PHP dans vos thèmes.</p>
	<p>Vos modules peuvent interroger PluXml pour y extraire des données.</p>
	<p>Vos modules peuvent se servir de fonctions interne au C.M.S.</p>
	<div class="alert orange grid"><p><strong>La prudence vous impose de ne pas modifier le cœur et les fichiers de PluXml </strong>, mais uniquement les données extraites le temps que vos scripts 
	les traitent et de créer vos propres fonctions si celles de PluXml sont incomplètes. <br><strong>La prudence vous impose aussi de vérifier 
	et de tester les modules d'autres personnes, avant d'en faire usage.</strong> </p></div>
	<h2>Le crochet magique.<small>(hook)</small></h2>
	<p><b><u>Le widget s’insère a partir d'un hook (code)</u> dans un ou plusieurs  fichiers de votre thème ou d'une page statique:</b></p>
	<p>Hook du widget à partir d'un fichier de votre thème:</p>
	<div class="ico" title="cliquez pour copier le code du widget"><b style="color:blue">&lt;?php eval($plxShow->callHook('moduleswidget','votreModule')); ?&gt;</b> &#128203;</div>
	<p>Hook du widget à partir d'une page statique:</p>
	<div class="ico" title="cliquez pour copier le code du widget"><b style="color:blue">&lt;?php eval($pthis->callHook('moduleswidget','votreModule')); ?&gt;</b> &#128203;</div>
	<h2>Fonctionnement du plugin</h2>
	<p>Le plugin ne fait qu'une chose par le biais de son hook, <br>il injecte dans vos page les textes ou scripts contenu dans un fichier installé dans son répertoire <b>plugins/modules/modules</b>.</p>
	<p>Pour appeler un module, il suffit de passer en paramètre le nom du fichier (sans son extension).</p>
	<h2>Puis je facilement créer mes modules?</h2>
	<p>Oui, il suffit de déposer dans le répertoire modules du plugin votre fichier avec l'extension php </p>
	<h3>exemple minimale</h3>
	<p>Dans le repertoire :<b>plugins/modules/modules</b></p>
	<ol>
		<li> Déposer un fichier vide  et du nom du module que vous voulez avec une extension PHP. Choisissez un mot simple et significatif par exemple: <b>exemple.php</b></li>
		<li>Éditer ce fichier et inserer la base minimale suivante dedans.
			<pre><code>&lt;?php if(!defined('PLX_ROOT')) exit;?>
	&lt;div id="&lt;?=$param ?>" class="modules">&lt;/div></code></pre>
			<p>Pour afficher Bonjour! dans la side bar, ajouter Bonjour! dans le code (boite div.module))</p>
			<pre><code>&lt;?php if(!defined('PLX_ROOT')) exit;?>
	&lt;div id="&lt;?=$param ?>" class="modules">Bonjour!&lt;/div></code></pre>
	<p style="text-align:end;color:purple"><sub>P.S. La première ligne teste si le module est dans l’environnement de PluXml avant de le charger, ne l'omettez pas.</sub></p>
		</li>
		<li>
			<p>Puis inserer dans le fichier sidebar.php de votre thème le code du hook du widget avec le nom de votre module en paramètre:<br>
			<b style="color:blue">&lt;?php eval($pthis->callHook('moduleswidget','exemple')); ?&gt;</b></p>
		</li>
		</ol>
		<p><b>Pour des modules plus complexes</b>, une structure HTML et un squelette testant la présence de fichier CSS et JS complémentaires est conseillé.</p>
			<p>La structure HTML</p>
			<ul class="html">
				<li>plugins/
					<ul>
						<li>modules/
							<ul>
								<li>modules/
									<li><i>votremodule.php</i></li>
									<li> votremodule/
										<ul>
											<li>css/
												<ul><li><i>votremodule.css</i></li></ul>
											</li>
											<li>js/
												<ul><li><i>votremodule.js</i></li></ul>
											</li>
											<li>img/
												<ul>
													<li><i>votremodule.webp</i></li>
													<li><i>ico-votremodule.png</i></li>
													<li> ... etc , images de votre module</li>
													</ul>
											</li>
											<li>votremoduleFiles/
												<ul>
													<li><i>Fichier1.html</i></li>
													<li><i>Fichier2.xml</i></li>
													<li><i>Fichier3.php</i></li>
													<li><i>admin.php<</li> si votre module peut-être configuré.</li>
													<li> etc ... les fichier et structure HTML dont vous avez besoin dans ce dossier pour ce module.</li>
												</ul>
											</li>
										</ul>
									</li>
								</ul>
							</li>
						</ul>
					</li>
				</ul>
			</li>
		</ul>
		<p>La structure de base du fichier module</p>
		<pre><code>&lt;?php if(!defined('PLX_ROOT')) exit; 
		
	# feuille de style du module, à ne charger qu'une fois
	if(file_exists(PLX_PLUGINS.'modules/modules/'.$module.'/css/'.$module.'.css') && !in_array(PLX_PLUGINS.'modules/modules/'.$module.'/css/'.$module.'.css',$plxPlug->css)){
		echo '&lt;link rel="stylesheet" href="plugins/modules/modules/'.$module.'/css/'.$module.'.css">';
		$plxPlug->css[]=PLX_PLUGINS.'modules/modules/'.$module.'/css/'.$module.'.css';
	}
	# fichier JavaScript du module, à ne charger qu'une fois
	if(file_exists(PLX_PLUGINS.'modules/modules/'.$module.'/js/'.$module.'.js')  && !in_array(PLX_PLUGINS.'modules/modules/'.$module.'/js/'.$module.'.js',$plxPlug->js)){
		echo '&lt;script src="'.PLX_PLUGINS.'modules/modules/'.$module.'/js/'.$module.'.js">&lt;/script>';
		$plxPlug->js[]= PLX_PLUGINS.'modules/modules/'.$module.'/js/'.$module.'.js';
	}
	# teste si un fichier json de configuration est présent dans le module
	if(file_exists(PLX_PLUGINS.'modules/modules/'.$module.'/js/'.$module.'.json')) {
	$init=json_decode(file_get_contents(PLX_PLUGINS.'modules/modules/'.$module.'/js/'.$module.'.json'), true);
	
	}
	else {
		/*$init = vos valeurs par défaut */
	}
	?>
	&lt;div id="&lt;?=$param ?>" class="modules">
		&lt;!-- texte HTML -->
		# et ou script PHP
		// votre code ici,la variable $param est disponible
		# exemple d'inclusion d'un fichier du module 
		//&lt;?php include($module.'/votremoduleFiles/fichier1.html'); ?>
		# exemple d'inclusion d'un fichier par le nom du second paramètre
		//&lt;?php include($module.'/votremoduleFiles/'.$param.'.php'); ?>
		# exemple d'inclusion d'un fichier admin.php
		&lt;?php include($module.'/'.$module.'Files/admin.php');?>
	&lt;/div>	</code></pre>
	<p>La boite <code style="color:blue">&lt;div id="votremodule" class="module">&lt;/div></code>vous permet d'encapsuler l'affichage de votre plugin et de le cibler 
		plus facilement via son <b>id</b> et sa <b>class</b> dans vos feuilles de styles et scripts.</p>
	<h3>exemple de structure de fichier admin.php</h3>
	<p style="text-align:end;color:purple">Ce fichier n'est chargé que si vous vous êtes préalablement connecté en tant qu'administrateur, c'est la premiere ligne du fichier.</p>
	<p>Que mettre au minimum dans ce fichier:</p>
	<pre><code>&lt;?php if(!defined('PLX_ROOT') || !isset($_SESSION['user']) && !isset($_SESSION['profil']) ) exit; ?>
&lt;?php if($_SESSION['profil'] != 0 ) exit; ?>
&lt;?php
if(isset($_POST[$param.'FormSubmit']))	{
	$json = PLX_PLUGINS.'modules/modules/'.$module.'/js/'.$module.'.json';

		if(file_exists($json)){	
			file_put_contents($json, json_encode(/* ici les données $_POST de votre formulaire */));
		}
		else {
			touch($json);
			file_put_contents($json, json_encode(/* ici les données $_POST de votre formulaire */));
		}
	}
}
# recupéré les données pour les affichée et préremplir vos elements de formulaire
$init=json_decode(file_get_contents(PLX_PLUGINS.'modules/modules/'.$module.'/js/'.$module.'.json', true));

?>
&lt;div id="admin-&lt;?= $param ?>" class="modules admin">
	&lt;label for="admin&lt;?= $param ?>">&lt;img src="&lt;?= 'plugins/modules/modules/'.$module.'/img/ico-'.$module.'.png"' ?> alt="admin &lt;?=$param ?>" title="administration du module &lt;?= $param ?>" class="adminModule" >&lt;/label>
	&lt;input type="checkbox" class="hidden" id ="admin&lt;?= $param ?>">
&lt;/div> 
&lt;div class="formModuleAdmin">
	&lt;header>&lt;label for="admin&lt;?= $param ?>"> X FERMER&lt;/label>
	&lt;h2>Administration module &lt;?= $param ?>&lt;/h2>&lt;/header>
	&lt;div>&lt;p>scripts et formulaire de configuration à develloper ou inclure dans ce fichier, exemple ci-dessous &lt;/p>
	&lt;form id="&lt;?= $param ?>Form" method="post">
	&lt;!-- vos elements de formulaire -->
	&lt;/form>
	&lt;/div>
&lt;/div></code></pre>
	<p>Le module mermaid fourni un exemple fonctionnel de page d'administration</p>

	</ol>
	<h2>Peut-on passer un parametre au module</h2>
	<p><b>Oui</b> Ce second paramètre est optionnel et prendra la valeur par défaut de l'unique paramètre passé.</p>
	<p>Le module en exemple, fourni plus bas,peut recevoir un paramètres et conditionné son script en fonction de celui-ci</p>
	<p>Le module mermaid peut chargé différents fichier texte (ecrit avec un format comparable au markdown) pour afficher des diagrammes et données graphiques </p>
	<p>Le principe est le même, il s'agit d'un nom de fichier sans extension, ce plugin utilise un sous répertoire à son nom. Par défaut, il chargera depuis ce sous-dossier le fichier portant son nom.</p>
	<h3>Des exemples?</h3>
	<p><b>Oui,</b>, c'est le rôle du module fourni, en éditant son fichier, vous verrez comment extraire de PluXml le nombre d'articles,
	catégories, commentaires, tags et pages statiques publié sur votre site.</p>		
	<p>Le plugin est livré avec un module exemple qui extrait quelques données de votre site et les affiche dans un camembert, <b>mermaid.php</b><p>
		<p><img src="../../plugins/modules/modules/mermaid/img/mermaid.png"></p>
		<p> Pour appeler ce module:</p>
	<div class="ico" title="cliquez pour copier le code du widget"><b style="color:blue">&lt;?php eval($plxShow->callHook('moduleswidget','mermaid')); ?&gt;</b> &#128203;</div>
	<h2>Fin</h2>
	<p>Si cette aide est insuffisante, <a href="https://forum.pluxml.org" target="_blank">le forum de pluxml</a> est l'endroit ou vous aurez le plus de chance d'obtenir de l'aide. L'auteur de ce plugin y passe fréquemment.</p>
	</div>
	<script>
		function copyDivToClipboard(el) {
			var range = document.createRange();
			range.selectNode(el);
			window.getSelection().removeAllRanges(); 
			window.getSelection().addRange(range); 
			document.execCommand("copy");
			window.getSelection().removeAllRanges();
			alert('Copié:\n\n'+el.textContent)
		}
		for (let e of document.querySelectorAll("div.ico ")) {
			e.addEventListener('click',function(){
				let el=e.querySelector('b');
				copyDivToClipboard(el);
			});
		}
	</script>
	<style>
		.help {max-width:960px;margin:auto;}
		.ico b {border:solid 1px slategray;background:#bee;border-radius:5px;padding:3px;}
		.help :is(h2,h3,h4) {color:#009EEB;text-decoration: 1px underline red}
		.help h1 {display:grid;color:#B5E61D;font-size:3.5em;font-weight:bold;-webkit-text-stroke:2px #009EEB;text-shadow:1px 1px 5px #009EEB;}
		li::marker {color:crimson;font-weight:bold;}
		.html {font-weight:bold;}
		.html i {color:blue}
		pre {border-inline-start:solid blue;padding:.5em;background:#efefef}
	</style>

==> modules.2.2.zip: lang/fr-help.php <==
<div class="help">
	<h1>Aide du plugin modules</h1>
	<img src="../../plugins/modules/icon.png" style="float:left">
	<p>Le plugin ne nécessite pas d'être configuré et est disponible sitôt activé</p>
	<p>La fonction de ce plugin se limite à injecter un widget dans vos pages.</p>
	<p> Ce widget pouvant embarquer différents modules, il peut-être utilisé plusieurs fois pour injecter différents modules dans vos pages à différents endroits.</p>
	<h2>A quoi sert ce widget?</h2>
	<p>Ce widget vous permet d'injecter dans vos page du texte( HTML, JavaScript,..)) et d'injecter du code PHP dans vos thèmes.</p>
	<p>Vos modules peuvent interroger PluXml pour y extraire des données.</p>
	<p>Vos modules peuvent se servir de fonctions interne au C.M.S.</p>
	<div class="alert orange grid"><p><strong>La prudence vous impose de ne pas modifier le cœur et les fichiers de PluXml </strong>, mais uniquement les données extraites le temps que vos scripts 
	les traitent et de créer vos propres fonctions si celles de PluXml sont incomplètes. <br><strong>La prudence vous impose aussi de vérifier 
	et de tester les modules d'autres personnes, avant d'en faire usage.</strong> </p></div>
	<h2>Le crochet magique.<small>(hook)</small></h2>
	<p><b><u>Le widget s’insère a partir d'un hook (code)</u> dans un ou plusieurs  fichiers de votre thème ou d'une page statique:</b></p>
	<p>Hook du widget à partir d'un fichier de votre thème:</p>
	<div class="ico" title="cliquez pour copier le code du widget"><b style="color:blue">&lt;?php eval($plxShow->callHook('moduleswidget','votreModule')); ?&gt;</b> &#128203;</div>
	<p>Hook du widget à partir d'une page statique:</p>
	<div class="ico" title="cliquez pour copier le code du widget"><b style="color:blue">&lt;?php eval($pthis->callHook('moduleswidget','votreModule')); ?&gt;</b> &#128203;</div>
	<h2>Fonctionnement du plugin</h2>
	<p>Le plugin ne fait qu'une chose par le biais de son hook, <br>il injecte dans vos page les textes ou scripts contenu dans un fichier installé dans son répertoire <b>plugins/modules/modules</b>.</p>
	<p>Pour appeler un module, il suffit de passer en paramètre le nom du fichier (sans son extension).</p>
	<h2>Puis je facilement créer mes modules?</h2>
	<p>Oui, il suffit de déposer dans le répertoire modules du plugin votre fichier avec l'extension php </p>
	<h3>exemple minimale</h3>
	<p>Dans le repertoire :<b>plugins/modules/modules</b></p>
	<ol>
		<li> Déposer un fichier vide  et du nom du module que vous voulez avec une extension PHP. Choisissez un mot simple et significatif par exemple: <b>exemple.php</b></li>
		<li>Éditer ce fichier et inserer la base minimale suivante dedans.
			<pre><code>&lt;?php if(!defined('PLX_ROOT')) exit;?>
	&lt;div id="&lt;?=$param ?>" class="modules">&lt;/div></code></pre>
			<p>Pour afficher Bonjour! dans la side bar, ajouter Bonjour! dans le code (boite div.module))</p>
			<pre><code>&lt;?php if(!defined('PLX_ROOT')) exit;?>
	&lt;div id="&lt;?=$param ?>" class="modules">Bonjour!&lt;/div></code></pre>
	<p style="text-align:end;color:purple"><sub>P.S. La première ligne teste si le module est dans l’environnement de PluXml avant de le charger, ne l'omettez pas.</sub></p>
		</li>
		<li>
			<p>Puis inserer dans le fichier sidebar.php de votre thème le code du hook du widget avec le nom de votre module en paramètre:<br>
			<b style="color:blue">&lt;?php eval($pthis->callHook('moduleswidget','exemple')); ?&gt;</b></p>
		</li>
		</ol>
		<p><b>Pour des modules plus complexes</b>, une structure HTML et un squelette testant la présence de fichier CSS et JS complémentaires est conseillé.</p>
			<p>La structure HTML</p>
			<ul class="html">
				<li>plugins/
					<ul>
						<li>modules/
							<ul>
								<li>modules/
									<li><i>votremodule.php</i></li>
									<li> votremodule/
										<ul>
											<li>css/
												<ul><li><i>votremodule.css</i></li></ul>
											</li>
											<li>js/
												<ul><li><i>votremodule.js</i></li></ul>
											</li>
											<li>img/
												<ul>
													<li><i>votremodule.webp</i></li>
													<li><i>ico-votremodule.png</i></li>
													<li> ... etc , images de votre module</li>
													</ul>
											</li>
											<li>votremoduleFiles/
												<ul>
													<li><i>Fichier1.html</i></li>
													<li><i>Fichier2.xml</i></li>
													<li><i>Fichier3.php</i></li>
													<li><i>admin.php<</li> si votre module peut-être configuré.</li>
													<li> etc ... les fichier et structure HTML dont vous avez besoin dans ce dossier pour ce module.</li>
												</ul>
											</li>
										</ul>
									</li>
								</ul>
							</li>
						</ul>
					</li>
				</ul>
			</li>
		</ul>
		<p>La structure de base du fichier module</p>
		<pre><code>&lt;?php if(!defined('PLX_ROOT')) exit; 
		
	# feuille de style du module, à ne charger qu'une fois
	if(file_exists(PLX_PLUGINS.'modules/modules/'.$module.'/css/'.$module.'.css') && !in_array(PLX_PLUGINS.'modules/modules/'.$module.'/css/'.$module.'.css',$plxPlug->css)){
		echo '&lt;link rel="stylesheet" href="plugins/modules/modules/'.$module.'/css/'.$module.'.css">';
		$plxPlug->css[]=PLX_PLUGINS.'modules/modules/'.$module.'/css/'.$module.'.css';
	}
	# fichier JavaScript du module, à ne charger qu'une fois
	if(file_exists(PLX_PLUGINS.'modules/modules/'.$module.'/js/'.$module.'.js')  && !in_array(PLX_PLUGINS.'modules/modules/'.$module.'/js/'.$module.'.js',$plxPlug->js)){
		echo '&lt;script src="'.PLX_PLUGINS.'modules/modules/'.$module.'/js/'.$module.'.js">&lt;/script>';
		$plxPlug->js[]= PLX_PLUGINS.'modules/modules/'.$module.'/js/'.$module.'.js';
	}
	# teste si un fichier json de configuration est présent dans le module
	if(file_exists(PLX_PLUGINS.'modules/modules/'.$module.'/js/'.$module.'.json')) {
	$init=json_decode(file_get_contents(PLX_PLUGINS.'modules/modules/'.$module.'/js/'.$module.'.json'), true);
	
	}
	else {
		/*$init = vos valeurs par défaut */
	}
	?>
	&lt;div id="&lt;?=$param ?>" class="modules">
		&lt;!-- texte HTML -->
		# et ou script PHP
		// votre code ici,la variable $param est disponible
		# exemple d'inclusion d'un fichier du module 
		//&lt;?php include($module.'/votremoduleFiles/fichier1.html'); ?>
		# exemple d'inclusion d'un fichier par le nom du second paramètre
		//&lt;?php include($module.'/votremoduleFiles/'.$param.'.php'); ?>
		# exemple d'inclusion d'un fichier admin.php
		&lt;?php include($module.'/'.$module.'Files/admin.php');?>
	&lt;/div>	</code></pre>
	<p>La boite <code style="color:blue">&lt;div id="votremodule" class="module">&lt;/div></code>vous permet d'encapsuler l'affichage de votre plugin et de le cibler 
		plus facilement via son <b>id</b> et sa <b>class</b> dans vos feuilles de styles et scripts.</p>
	<h3>exemple de structure de fichier admin.php</h3>
	<p style="text-align:end;color:purple">Ce fichier n'est chargé que si vous vous êtes préalablement connecté en tant qu'administrateur, c'est la premiere ligne du fichier.</p>
	<p>Que mettre au minimum dans ce fichier:</p>
	<pre><code>&lt;?php 
	if(!defined('PLX_ROOT') ) exit; 
	
	if(isset($_SESSION['user']) && isset($_SESSION['profil']) && $_SESSION['profil'] == '0'  )	{
		if(isset($_POST[$param.'FormSubmit'])){
		$json = PLX_PLUGINS.'modules/modules/'.$module.'/js/'.$module.'.json';
		if(isset($_POST['mermaidThemes'])) {
			if(file_exists($json)){	
				file_put_contents($json, json_encode(trim($_POST['mermaidThemes'])));
			}
			else {
				touch($json);
				file_put_contents($json, json_encode(trim($_POST['mermaidThemes'])));
			}
			
		}
		}
	$selectThemes = array('default','neutral','dark','forest','base');
	$selectOptions='';
	# recupéré les données pour les affichée et préremplir vos elements de formulaire
	$init=json_decode(file_get_contents(PLX_PLUGINS.'modules/modules/'.$module.'/js/'.$module.'.json', true));

?>
&lt;-- feuilles de styles du formulaires -->
&lt;div id="admin-&lt;?= $param ?>" class="modules admin">
	&lt;label for="admin&lt;?= $param ?>">&lt;img src="&lt;?= 'plugins/modules/modules/'.$module.'/img/ico-'.$module.'.png"' ?> alt="admin &lt;?=$param ?>" title="administration du module &lt;?= $param ?>" class="adminModule" >&lt;/label>
	&lt;input type="checkbox" class="hidden" id ="admin&lt;?= $param ?>">
&lt;/div> 
&lt;div class="formModuleAdmin">
	&lt;header>&lt;label for="admin&lt;?= $param ?>"> X FERMER&lt;/label>
	&lt;h2>Administration module &lt;?= $param ?>&lt;/h2>&lt;/header>
	&lt;div>&lt;p>scripts et formulaire de configuration à develloper ou inclure dans ce fichier, exemple ci-dessous &lt;/p>
	&lt;form id="&lt;?= $param ?>Form" method="post">
	&lt;!-- vos elements de formulaire -->
	&lt;/form>
	&lt;/div>
&lt;/div>
&lt;-- scripts du formulaires -->
&lt;?php } ?></code></pre>
	<p>Le module mermaid fourni un exemple fonctionnel de page d'administration</p>

	</ol>
	<h2>Peut-on passer un parametre au module</h2>
	<p><b>Oui</b> Ce second paramètre est optionnel et prendra la valeur par défaut de l'unique paramètre passé.</p>
	<p>Le module en exemple, fourni plus bas,peut recevoir un paramètres et conditionné son script en fonction de celui-ci</p>
	<p>Le module mermaid peut chargé différents fichier texte (ecrit avec un format comparable au markdown) pour afficher des diagrammes et données graphiques </p>
	<p>Le principe est le même, il s'agit d'un nom de fichier sans extension, ce plugin utilise un sous répertoire à son nom. Par défaut, il chargera depuis ce sous-dossier le fichier portant son nom.</p>
	<h3>Des exemples?</h3>
	<p><b>Oui,</b>, c'est le rôle du module fourni, en éditant son fichier, vous verrez comment extraire de PluXml le nombre d'articles,
	catégories, commentaires, tags et pages statiques publié sur votre site.</p>		
	<p>Le plugin est livré avec un module exemple qui extrait quelques données de votre site et les affiche dans un camembert, <b>mermaid.php</b><p>
		<p><img src="../../plugins/modules/modules/mermaid/img/mermaid.png"></p>
		<p> Pour appeler ce module:</p>
	<div class="ico" title="cliquez pour copier le code du widget"><b style="color:blue">&lt;?php eval($plxShow->callHook('moduleswidget','mermaid')); ?&gt;</b> &#128203;</div>
	<h2>Fin</h2>
	<p>Si cette aide est insuffisante, <a href="https://forum.pluxml.org" target="_blank">le forum de pluxml</a> est l'endroit ou vous aurez le plus de chance d'obtenir de l'aide. L'auteur de ce plugin y passe fréquemment.</p>
	</div>
	<script>
		function copyDivToClipboard(el) {
			var range = document.createRange();
			range.selectNode(el);
			window.getSelection().removeAllRanges(); 
			window.getSelection().addRange(range); 
			document.execCommand("copy");
			window.getSelection().removeAllRanges();
			alert('Copié:\n\n'+el.textContent)
		}
		for (let e of document.querySelectorAll("div.ico ")) {
			e.addEventListener('click',function(){
				let el=e.querySelector('b');
				copyDivToClipboard(el);
			});
		}
	</script>
	<style>
		.help {max-width:960px;margin:auto;}
		.ico b {border:solid 1px slategray;background:#bee;border-radius:5px;padding:3px;}
		.help :is(h2,h3,h4) {color:#009EEB;text-decoration: 1px underline red}
		.help h1 {display:grid;color:#B5E61D;font-size:3.5em;font-weight:bold;-webkit-text-stroke:2px #009EEB;text-shadow:1px 1px 5px #009EEB;}
		li::marker {color:crimson;font-weight:bold;}
		.html {font-weight:bold;}
		.html i {color:blue}
		pre {border-inline-start:solid blue;padding:.5em;background:#efefef}
	</style>
